API reference
=============

sokoenginepy.io
---------------

.. automodule:: sokoenginepy.io

.. toctree::
    :maxdepth: 4

    _api_py/puzzle
    _api_py/snapshot
    _api_py/collection


sokoenginepy.game
-----------------

.. automodule:: sokoenginepy.game

.. toctree::
    :maxdepth: 4

    _api_py/game_config
    _api_py/tessellation
    _api_py/board_graph
    _api_py/board_manager
    _api_py/mover
